# Products
This is a list of every CRM product in the database where you can modify, delete and add new products. Typing in the search field filters the products by name.

## Columns:
Each column title has three lines on the right if you hover over it. Click on them to show options for that column. The second tab of the options menu will allow you to filter the column, the third to completely hide entire columns. Click on anywhere else on the column to order it, cycling between ascending, descending and no ordering. Hold shift while clicking to order multiple columns with individual weights.

### Title:
The name of the product.

### Is Competitor:
Indicates if this is a competitor's product.
